@@ -13,7 +13,6 @@ mainwindow::mainwindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
     ui->setupUi(this);
-    ui->scrollArea->setWidget(ui->widget);
 
     if (!QFile::exists("/opt/cssutransitionstuner/cssuinstalled")) {
         ui->blurless->setDisabled(true);
@@ -28,10 +27,12 @@ mainwindow::mainwindow(QWidget *parent) :
     if (!QFile::exists("/opt/cssutransitionstuner/tactileinstalled")) {
         ui->tactile->setDisabled(true);
     }
+
+    ui->buttonBox->button(QDialogButtonBox::Help)->setText(tr("About"));
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     orientationChanged();
     readvalues();
-    abouttext = "CSSU Transitions Tuner ver. 0.0.7<br /><br />Auhtor: d-iivil<br />Licence: GPL";
+    abouttext = "CSSU Transitions Tuner ver. 0.0.8<br /><br />Auhtor: d-iivil<br />Licence: GPL";
 }
 
 mainwindow::~mainwindow()
@@ -44,15 +45,11 @@ void mainwindow::orientationChanged()
      QRect screenGeometry = QApplication::desktop()->screenGeometry();
      if (screenGeometry.width() > screenGeometry.height())
      {
-         ui->widget_bot->setVisible(false);
-         ui->widget_right->setVisible(true);
-
-         //ui->listWidget->setMaximumWidth(720);
+	 ui->gridLayout->addWidget(ui->buttonBox, 0, 1, 1, 1);
      }
      else
      {
-         ui->widget_bot->setVisible(true);
-         ui->widget_right->setVisible(false);
+	 ui->gridLayout->addWidget(ui->buttonBox, 1, 0, 1, 1);
      }
 
 }
@@ -425,50 +422,30 @@ void mainwindow::storevalues()
 
 
 }
-void mainwindow::on_pushButton_clicked()
+
+
+void mainwindow::on_buttonBox_clicked(QAbstractButton* button)
 {
-    ui->pushButton->setDisabled(true);
-    // sleep(1);
-    storevalues();
-    // QMaemo5InformationBox::information(this, tr("Settings saved."), QMaemo5InformationBox::DefaultTimeout);
-    //QMaemo5InformationBox::information(this, tr("Transitions updated!") +  "<br /><br />" + tr("Some changes requires restarting the device to activate them."), QMaemo5InformationBox::NoTimeout);
-
-    QMessageBox msgBox;
-    msgBox.setWindowTitle("CSSU Transitions Tuner");
-    msgBox.setText("Transitions updated! <br /><br />Reboot is required to activate all changes.");
-    msgBox.exec();
-
-    ui->pushButton->setEnabled(true);
-}
-
-void mainwindow::on_pushButton_2_clicked()
-{
-    QMessageBox msgBox;
-    msgBox.setWindowTitle("CSSU Transitions Tuner");
-    msgBox.setText(abouttext);
-    msgBox.exec();
-}
-
-void mainwindow::on_pushButton_3_clicked()
-{
-    ui->pushButton->setDisabled(true);
-    // sleep(1);
-    storevalues();
-    // QMaemo5InformationBox::information(this, tr("Settings saved."), QMaemo5InformationBox::DefaultTimeout);
-    //QMaemo5InformationBox::information(this, tr("Transitions updated!") +  "<br /><br />" + tr("Some changes requires restarting the device to activate them."), QMaemo5InformationBox::NoTimeout);
-
-    QMessageBox msgBox;
-    msgBox.setWindowTitle("CSSU Transitions Tuner");
-    msgBox.setText("Transitions updated! <br /><br />Reboot is required to activate all changes.");
-    msgBox.exec();
-
-    ui->pushButton->setEnabled(true);
-}
-
-void mainwindow::on_pushButton_5_clicked()
-{
-    QMessageBox msgBox;
-    msgBox.setWindowTitle("CSSU Transitions Tuner");
-    msgBox.setText(abouttext);
-    msgBox.exec();
+    QDialogButtonBox::ButtonRole role=ui->buttonBox->buttonRole(button);
+    switch(role)
+    {
+	case QDialogButtonBox::HelpRole:
+	{
+	    QMessageBox msgBox;
+	    msgBox.setWindowTitle("CSSU Transitions Tuner");
+	    msgBox.setText(abouttext);
+	    msgBox.exec();
+	    break;
+	}
+	case QDialogButtonBox::AcceptRole:
+	{
+            storevalues();
+	    QMessageBox msgBox;
+	    msgBox.setWindowTitle("CSSU Transitions Tuner");
+	    msgBox.setText("Transitions updated! <br /><br />Reboot is required to activate all changes.");
+	    msgBox.exec();
+	    break;
+	}
+	default:;
+    }
 }
