@@ -25,14 +25,9 @@ public:
 private:
     Ui::mainwindow *ui;
 
-
-
 private slots:
-    void on_pushButton_5_clicked();
-    void on_pushButton_3_clicked();
-    void on_pushButton_2_clicked();
-    void on_pushButton_clicked();
     void orientationChanged();
+    void on_buttonBox_clicked(QAbstractButton* button);
 };
 
 #endif // MAINWINDOW_H
